==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/EnvoyFilterFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class EnvoyFilterFluentImpl<A extends EnvoyFilterFluent<A>> extends BaseFluent<A> implements EnvoyFilterFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private EnvoyFilterSpecBuilder spec;

    public EnvoyFilterFluentImpl(){
    }
    public EnvoyFilterFluentImpl(EnvoyFilter instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public EnvoyFilterFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public EnvoyFilterFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public EnvoyFilterFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public EnvoyFilterFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public EnvoyFilterFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public EnvoyFilterSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public EnvoyFilterSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(EnvoyFilterSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new EnvoyFilterSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public EnvoyFilterFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public EnvoyFilterFluent.SpecNested<A> withNewSpecLike(EnvoyFilterSpec item){
            return new SpecNestedImpl(item);
    }

    public EnvoyFilterFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public EnvoyFilterFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new EnvoyFilterSpecBuilder().build());
    }

    public EnvoyFilterFluent.SpecNested<A> editOrNewSpecLike(EnvoyFilterSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            EnvoyFilterFluentImpl that = (EnvoyFilterFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<EnvoyFilterFluent.MetadataNested<N>> implements EnvoyFilterFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) EnvoyFilterFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends EnvoyFilterSpecFluentImpl<EnvoyFilterFluent.SpecNested<N>> implements EnvoyFilterFluent.SpecNested<N>,Nested<N>{

            private final EnvoyFilterSpecBuilder builder;
    
            SpecNestedImpl(EnvoyFilterSpec item){
                    this.builder = new EnvoyFilterSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new EnvoyFilterSpecBuilder(this);
            }
    
    public N and(){
            return (N) EnvoyFilterFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/EnvoyFilterFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class EnvoyFilterFluentImpl<A extends EnvoyFilterFluent<A>> extends BaseFluent<A> implements EnvoyFilterFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private EnvoyFilterSpecBuilder spec;

    public EnvoyFilterFluentImpl(){
    }
    public EnvoyFilterFluentImpl(EnvoyFilter instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public EnvoyFilterFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public EnvoyFilterFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public EnvoyFilterFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public EnvoyFilterFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public EnvoyFilterFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public EnvoyFilterSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public EnvoyFilterSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(EnvoyFilterSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new EnvoyFilterSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public EnvoyFilterFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public EnvoyFilterFluent.SpecNested<A> withNewSpecLike(EnvoyFilterSpec item){
            return new SpecNestedImpl(item);
    }

    public EnvoyFilterFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public EnvoyFilterFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new EnvoyFilterSpecBuilder().build());
    }

    public EnvoyFilterFluent.SpecNested<A> editOrNewSpecLike(EnvoyFilterSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            EnvoyFilterFluentImpl that = (EnvoyFilterFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<EnvoyFilterFluent.MetadataNested<N>> implements EnvoyFilterFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) EnvoyFilterFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends EnvoyFilterSpecFluentImpl<EnvoyFilterFluent.SpecNested<N>> implements EnvoyFilterFluent.SpecNested<N>,Nested<N>{

            private final EnvoyFilterSpecBuilder builder;
    
            SpecNestedImpl(EnvoyFilterSpec item){
                    this.builder = new EnvoyFilterSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new EnvoyFilterSpecBuilder(this);
            }
    
    public N and(){
            return (N) EnvoyFilterFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}
